==> SjisTk-0.01.tar.gz: SjisTk-0.01/SjisTk/JA.pm <==
1;
__END__

=pod

=encoding Shift_JIS

=head1 \tgEFA

SjisTk-JA - Tk modules on Microsoft Windows with Sjis software (Japanese document)

=head1 Tv

   use Sjis 0.64;
   use Tk;

=head1 v

̃\tgEFA Microsoft Windows  Sjis \tgEFȂgĎgp
 Tk W[łB

JPerl ŋLq Perl/Tk AvP[V Perl5.8 ܂͂ȍ~ɈڐA
Ƃɖ𗧂܂B

=head1 \tgEFÄꗗ

   SjisTk::Button.pm
   SjisTk::Canvas.pm
   SjisTk::Checkbutton.pm
   SjisTk::ColorEditor.pm
   SjisTk::Dialog.pm
   SjisTk::DialogBox.pm
   SjisTk::Entry.pm
   SjisTk::Frame.pm
   SjisTk::Label.pm
   SjisTk::LabFrame.pm
   SjisTk::Listbox.pm
   SjisTk::MainWindow.pm
   SjisTk::Menu.pm
   SjisTk::Message.pm
   SjisTk::Radiobutton.pm
   SjisTk::ROText.pm
   SjisTk::Scale.pm
   SjisTk::Table.pm
   SjisTk::Text.pm
   SjisTk::Toplevel.pm

=head1 oOƐ

oO񍐁Apb`}܂B

=head1 

̃vWFNg t  ina@cpan.org ɂĎn܂܂B

=head1 쌠

̃\tgEFA̓t[\tgEFAłBȂ Perl ƓCZX
̌ōĔzzyѕύXsƂo܂Bڂ perlartistic QƂ
B

̃\tgEFA͗Lpł邱ƂĔЕz܂A*S̖ۏ* 
łBƉ\̕ۏ؂̖ړIւ̓ḰAOɎꂽ̂
ߑS݂܂B

=head1 Ql

 vO~OPerl 
 By Larry Wall, Tom Christiansen, Randal L. Schwartz, ߓ Ð 
 1997N12 s
 759y[W
 ISBN 4-900900-48-6
 http://www.oreilly.co.jp/out/pperl/index.htm

 vO~OPerl 3 VOLUME 1
 By Larry Wall, Tom Christiansen, Jon Orwant, ߓ Ð 
 2002N09 s
 756y[W
 ISBN 4-87311-096-3
 http://www.oreilly.co.jp/books/4873110963/

 vO~OPerl 3 VOLUME 2
 By Larry Wall, Tom Christiansen, Jon Orwant, ߓ Ð 
 2002N09 s
 680y[W
 ISBN 4-87311-097-1
 http://www.oreilly.co.jp/books/4873110971/

 PerlNCbNt@X
 By Stephen Spainhour, Ellen Siever, Nathan Patwardhan, ߓ Ð,  \ Ė
 2000N03 s
 784y[W
 ISBN 4-900900-72-9
 http://www.oreilly.co.jp/books/4900900729/

 Perl/Tk
 By Nancy Walsh AΑ] M,  FK 
 1999N12 s
 440y[W
 ISBN 4-87311-008-4
 http://www.oreilly.co.jp/books/4873110084/

=head1 ӎ

̃\tgEFÁAȉ̕X̍쐬\tgEFAѕ̂ɂ쐬
܂BSĂ̕Ɋӂ܂B

 Larry Wall, Perl
 http://www.perl.org/

 Nick Ing-Simmons, Tk
 http://search.cpan.org/~ni-s/Tk-804.027/

 Slaven Rezic, Tk
 http://search.cpan.org/~srezic/Tk-804.028_503/

 n[hȃ\tg̘b, Perl/Tkœ{̃tH_g(Win32)
 http://hardsoft.at.webry.info/200802/article_5.html

 ЂƂ炸 2.0 , WindowsPerl/Tk̃j[o[{ꉻ@(1) 
 http://home.hiroshima-u.ac.jp/m072848/blog/blosxom.cgi/perl/tk/japanese/menu.htm

  e, Encode W[
 http://search.cpan.org/dist/Encode/

=cut

==> SjisTk-0.02.tar.gz: SjisTk-0.02/SjisTk/JA.pm <==
1;
__END__

=pod

=encoding Shift_JIS

=head1 \tgEFA

SjisTk-JA - Tk modules on Microsoft Windows with Sjis software (Japanese document)

=head1 Tv

   use Sjis 0.64;
   use Tk;

=head1 v

̃\tgEFA Microsoft Windows  Sjis \tgEFAɂ Tk
{ꉻ邽߂̃W[łB

JPerl ŋLq Perl/Tk AvP[V Perl5.8 ܂͂ȍ~ɈڐA
Ƃɖ𗧂܂B

=head1 \tgEFÄꗗ

   SjisTk::Button.pm
   SjisTk::Canvas.pm
   SjisTk::Checkbutton.pm
   SjisTk::ColorEditor.pm
   SjisTk::Dialog.pm
   SjisTk::DialogBox.pm
   SjisTk::Entry.pm
   SjisTk::Frame.pm
   SjisTk::Label.pm
   SjisTk::LabFrame.pm
   SjisTk::Listbox.pm
   SjisTk::MainWindow.pm
   SjisTk::Menu.pm
   SjisTk::Message.pm
   SjisTk::Radiobutton.pm
   SjisTk::ROText.pm
   SjisTk::Scale.pm
   SjisTk::Table.pm
   SjisTk::Text.pm
   SjisTk::Toplevel.pm

=head1 oOƐ

oO񍐁Apb`}܂B

=head1 

̃vWFNg t  ina@cpan.org ɂĎn܂܂B

=head1 쌠

̃\tgEFA̓t[\tgEFAłBȂ Perl ƓCZX
̌ōĔzzyѕύXsƂo܂Bڂ perlartistic QƂ
B

̃\tgEFA͗Lpł邱ƂĔЕz܂A*S̖ۏ* 
łBƉ\̕ۏ؂̖ړIւ̓ḰAOɎꂽ̂
ߑS݂܂B

=head1 Ql

 vO~OPerl 
 By Larry Wall, Tom Christiansen, Randal L. Schwartz, ߓ Ð 
 1997N12 s
 759y[W
 ISBN 4-900900-48-6
 http://www.oreilly.co.jp/out/pperl/index.htm

 vO~OPerl 3 VOLUME 1
 By Larry Wall, Tom Christiansen, Jon Orwant, ߓ Ð 
 2002N09 s
 756y[W
 ISBN 4-87311-096-3
 http://www.oreilly.co.jp/books/4873110963/

 vO~OPerl 3 VOLUME 2
 By Larry Wall, Tom Christiansen, Jon Orwant, ߓ Ð 
 2002N09 s
 680y[W
 ISBN 4-87311-097-1
 http://www.oreilly.co.jp/books/4873110971/

 PerlNCbNt@X
 By Stephen Spainhour, Ellen Siever, Nathan Patwardhan, ߓ Ð,  \ Ė
 2000N03 s
 784y[W
 ISBN 4-900900-72-9
 http://www.oreilly.co.jp/books/4900900729/

 Perl/Tk
 By Nancy Walsh AΑ] M,  FK 
 1999N12 s
 440y[W
 ISBN 4-87311-008-4
 http://www.oreilly.co.jp/books/4873110084/

=head1 ӎ

̃\tgEFÁAȉ̕X̍쐬\tgEFAѕ̂ɂ쐬
܂BSĂ̕Ɋӂ܂B

 Larry Wall, Perl
 http://www.perl.org/

 Nick Ing-Simmons, Tk
 http://search.cpan.org/~ni-s/Tk-804.027/

 Slaven Rezic, Tk
 http://search.cpan.org/~srezic/Tk-804.028_503/

 n[hȃ\tg̘b, Perl/Tkœ{̃tH_g(Win32)
 http://hardsoft.at.webry.info/200802/article_5.html

 ЂƂ炸 2.0 , WindowsPerl/Tk̃j[o[{ꉻ@(1) 
 http://home.hiroshima-u.ac.jp/m072848/blog/blosxom.cgi/perl/tk/japanese/menu.htm

  e, Encode W[
 http://search.cpan.org/dist/Encode/

=cut
